@@ -1,5 +1,5 @@
 /* Tower Toppler - Nebulus
- * Copyright (C) 2000-2003  Andreas Rver
+ * Copyright (C) 2000-2004  Andreas Rver
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -57,7 +57,7 @@ void configuration::parse(FILE * in) {
             if (atoi(param) > 0)
               key_redefine((ttkey)t->maxlen, (SDLKey)atoi(param));
             break;
-          default: assert(0, _("Unknown config data type."));
+          default: assert(0, "Unknown config data type.");
           }
           break;
         }
@@ -171,7 +171,7 @@ configuration::~configuration(void) {
       case CT_KEY:
         fprintf(f, "%i", (int)key_conv2sdlkey((ttkey)t->maxlen, true));
         break;
-      default: assert(0, _("Unknown config data type."));
+      default: assert(0, "Unknown config data type.");
       }
 
       fprintf(f, "\n");
