@@ -1,5 +1,5 @@
 /* Tower Toppler - Nebulus
- * Copyright (C) 2000-2003  Andreas Rver
+ * Copyright (C) 2000-2004  Andreas Rver
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,6 +19,8 @@
 #ifndef CONFIGURATION_H
 #define CONFIGURATION_H
 
+#include "decl.h"
+
 #include <stdio.h>
 
 #define TOWERNAMELEN 19
@@ -89,7 +91,7 @@ public:
   void curr_password(char pwd[PASSWORD_LEN+1]);
 
   int  debug_level() const { return i_debug_level; }
-  void debug_level(int l) { need_save = true; i_debug_level = l; }
+  void debug_level(int l) { need_save = true; i_debug_level = l; dcl_setdebuglevel(l); }
 
   int  game_speed() const { return i_game_speed; }
   void game_speed(int spd) { need_save = true; i_game_speed = spd; }
