@@ -1,5 +1,5 @@
 /* Tower Toppler - Nebulus
- * Copyright (C) 2000-2003  Andreas Rver
+ * Copyright (C) 2000-2004  Andreas Rver
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -74,7 +74,7 @@ void gam_arrival(void) {
   b = 5;
   toppler = 1;
 
-  snd_start();
+  //TTSound->startsound(SND_START);
   top_hide();
 
   key_readkey();
@@ -85,7 +85,7 @@ void gam_arrival(void) {
     scr_writetext_center((SCREENHEI / 6), _("You are entering the"));
 
     if (strlen(lev_towername()))
-      scr_writetext_center((SCREENHEI*2 / 6), gettext(lev_towername()));
+      scr_writetext_center((SCREENHEI*2 / 6), _(lev_towername()));
     else
       scr_writetext_center((SCREENHEI*2 / 6), _("Nameless Tower"));
 
@@ -95,12 +95,12 @@ void gam_arrival(void) {
       scr_writetext_center(SCREENHEI * 5 / 6, buf);
     }
     scr_swap();
-    snd_play();
+    ttsounds::instance()->play();
 
     switch (b) {
 
     case 5:
-      snd_start();
+      //ttsounds::instance()->startsound(SND_START);
       b = 6;
       delay = 0;
       break;
@@ -109,7 +109,7 @@ void gam_arrival(void) {
       delay++;
       if (delay == 10) {
         b = 0;
-        snd_sub_raise();
+        //ttsounds::instance()->startsound(SND_SUB_RAISE);
       }
       break;
 
@@ -140,7 +140,7 @@ void gam_arrival(void) {
       subshape--;
       if (subshape == 9) {
         b = 4;
-        snd_sub_down();
+        //ttsounds::instance()->startsound(SND_SUB_DOWN);
       }
       break;
 
@@ -274,7 +274,7 @@ static unsigned short towerpos(int verticalpos, int &tower_position, int anglepo
   sts_move(j, i);
   tower_position += i;
 
-  snd_watervolume(verticalpos > 100 ? 30 : 128 - verticalpos);
+  ttsounds::instance()->setsoundvol(SND_WATER, verticalpos > 100 ? 30 : 128 - verticalpos);
 
   return tower_position;
 }
@@ -366,24 +366,24 @@ static void bonus(int &tower_position, int &tower_angle, int time, bool lifes) {
   while (zeit > 0) {
     dcl_wait();
     countdown(zeit, 10);
-    snd_score();
-    snd_play();
+    ttsounds::instance()->startsound(SND_SCORE);
+    ttsounds::instance()->play();
     writebonus(tower_position, tower_angle, zeit, tec, extra, time, lif, lifes);
   }
 
   while (tec > 0) {
     dcl_wait();
     countdown(tec, 10);
-    snd_score();
-    snd_play();
+    ttsounds::instance()->startsound(SND_SCORE);
+    ttsounds::instance()->play();
     writebonus(tower_position, tower_angle, zeit, tec, extra, time, lif, lifes);
   }
 
   while (extra > 0) {
     dcl_wait();
     countdown(extra, 10);
-    snd_score();
-    snd_play();
+    ttsounds::instance()->startsound(SND_SCORE);
+    ttsounds::instance()->play();
     writebonus(tower_position, tower_angle, zeit, tec, extra, time, lif, lifes);
   }
 
@@ -391,8 +391,8 @@ static void bonus(int &tower_position, int &tower_angle, int time, bool lifes) {
     while (lif > 0) {
       dcl_wait();
       countdown(lif, 5000);
-      snd_score();
-      snd_play();
+      ttsounds::instance()->startsound(SND_SCORE);
+      ttsounds::instance()->play();
       writebonus(tower_position, tower_angle, zeit, tec, extra, time, lif, lifes);
     }
   }
@@ -413,7 +413,7 @@ static void akt_time(int &time, int &timecount, gam_states &state) {
       timecount = 0;
       time--;
       if ((time >= 0) && (time <= 20 || (time <= 40 && (time % 2))))
-        snd_alarm();
+	  ttsounds::instance()->startsound(SND_ALARM);
       if (time == 0)
         state = STATE_TIMEOUT;
     }
@@ -453,7 +453,7 @@ static void get_keys(Sint8 &left_right, Sint8 &up_down, bool &space, Uint16 ksta
 
 static void escape(gam_states &state, int &tower_position, int &tower_anglepos, int time) {
 
-  snd_wateroff();
+  ttsounds::instance()->stopsound(SND_WATER);
 
   bg_tower_pos = tower_position;
   bg_tower_angle = tower_anglepos;
@@ -463,14 +463,14 @@ static void escape(gam_states &state, int &tower_position, int &tower_anglepos,
   if (men_game())
     state = STATE_ABORTED;
 
-  snd_wateron();
+  ttsounds::instance()->startsound(SND_WATER);
   towerpos(top_verticalpos(), tower_position,
            top_anglepos(), tower_anglepos);
 }
 
 static void pause(int &tower_position, int tower_anglepos, int time) {
 
-  snd_wateroff();
+  ttsounds::instance()->stopsound(SND_WATER);
 
   bg_tower_pos = tower_position;
   bg_tower_angle = tower_anglepos;
@@ -479,7 +479,7 @@ static void pause(int &tower_position, int tower_anglepos, int time) {
   set_men_bgproc(game_background_proc);
   men_info(_("Pause"), -1, 1);
 
-  snd_wateron();
+  ttsounds::instance()->startsound(SND_WATER);
   towerpos(top_verticalpos(), tower_position,
            top_anglepos(), tower_anglepos);
 }
@@ -517,8 +517,7 @@ gam_result gam_towergame(Uint8 &anglepos, Uint16 &resttime, int &demo, void *dem
   if (demo < 0) drawflags = SF_REC;
   else if (demo > 0) drawflags = SF_DEMO;
 
-  assert(!(demo && !demobuf), _("Trying to play or record a null demo."));
-
+  assert(!(demo && !demobuf), "Trying to play or record a null demo.");
 
   top_init();
 
@@ -591,7 +590,7 @@ gam_result gam_towergame(Uint8 &anglepos, Uint16 &resttime, int &demo, void *dem
     scr_drawall(towerpos(top_verticalpos(), tower_position,
                          top_anglepos(), tower_angle), (4 - top_anglepos()) & 0x7f, time, false, 0, 0, drawflags);
     scr_swap();
-    snd_play();
+    ttsounds::instance()->play();
     dcl_wait();
   } while (!top_ended() && (state == STATE_PLAYING));
 
@@ -613,12 +612,12 @@ gam_result gam_towergame(Uint8 &anglepos, Uint16 &resttime, int &demo, void *dem
     while (lev_towerrows() > tower_position / 4 + 4) {
 
       lev_removelayer(lev_towerrows()-1);
-      snd_crumble();
+      ttsounds::instance()->startsound(SND_CRUMBLE);
       rob_update();
       scr_drawall(towerpos(top_verticalpos(), tower_position,
                            top_anglepos(), tower_angle), (4 - top_anglepos()) & 0x7f, time, false, 0, 0, drawflags);
       scr_swap();
-      snd_play();
+      ttsounds::instance()->play();
 
       dcl_wait();
 
@@ -629,7 +628,7 @@ gam_result gam_towergame(Uint8 &anglepos, Uint16 &resttime, int &demo, void *dem
 
       if (top_verticalpos() > 8) {
         lev_removelayer(top_verticalpos() / 4 - 2);
-        snd_crumble();
+        ttsounds::instance()->startsound(SND_CRUMBLE);
         top_drop1layer();
       }
 
@@ -637,7 +636,7 @@ gam_result gam_towergame(Uint8 &anglepos, Uint16 &resttime, int &demo, void *dem
       scr_drawall(towerpos(top_verticalpos(), tower_position,
                            top_anglepos(), tower_angle), (4 - top_anglepos()) & 0x7f, time, false, 0, 0, drawflags);
       scr_swap();
-      snd_play();
+      ttsounds::instance()->play();
 
       dcl_wait();
     }
