@@ -1,5 +1,5 @@
 /* Tower Toppler - Nebulus
- * Copyright (C) 2000-2003  Andreas Rver
+ * Copyright (C) 2000-2004  Andreas Rver
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -22,7 +22,6 @@
 
 #include <stdlib.h>
 #include <string.h>
-#include <unistd.h>
 #include <stdio.h>
 #include <fcntl.h>
 
@@ -32,6 +31,8 @@
 
 #if (SYSTEM != SYS_LINUX)
 #define gid_t int
+#else
+#include <unistd.h>
 #endif
 /* the group ids of the game */
 static gid_t UserGroupID, GameGroupID;
@@ -238,9 +239,9 @@ void hsc_init(void) {
   /* no dir to the global highscore table -> not global highscore table */
 
   if (globalHighscore)
-    printf(_("using global highscore at %s\n"), highscoreName);
+    debugprintf(2, "using global highscore at %s\n", highscoreName);
   else
-    printf(_("using local highscore at %s\n"), highscoreName);
+    debugprintf(2, "using local highscore at %s\n", highscoreName);
 
 #else // (SYSTEM == SYS_LINUX)
 
