@@ -1,5 +1,5 @@
 /* Tower Toppler - Nebulus
- * Copyright (C) 2000-2003  Andreas Rver
+ * Copyright (C) 2000-2004  Andreas Rver
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -16,16 +16,20 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
+#ifndef CREATOR
+
 #include "level.h"
 
 #include "points.h"
 #include "archi.h"
-#include "decl.h"
 #include "configuration.h"
 #include "screen.h"
 
-#include <string.h>
+#endif
+
+#include "decl.h"
 #include <stdlib.h>
+#include <string.h>
 
 #define TOWERWID 16
 
@@ -67,6 +71,10 @@ struct _tblockdata {
     { "lift top",          0,  TBF_STATION|TBF_PLATFORM },
     { "lift middle",       0,  TBF_STATION|TBF_PLATFORM },
     { "lift bottom",      '^', TBF_STATION|TBF_PLATFORM },
+    { "stick at door",     0,  },
+    { "stick at target",   0,  },
+    { "lift at door",      0 , TBF_STATION|TBF_PLATFORM },
+    { "lift at target",    0 , TBF_STATION|TBF_PLATFORM },
 };
 
 /* Sections in the data files; do not change the order,
@@ -111,17 +119,21 @@ typedef struct mission_node {
 
 mission_node * missions;
 
+#ifndef CREATOR
+
 static int missionfiles (const struct dirent *file)
 {
   int len = strlen(file->d_name);
 
   return ((len > 4) &&
-	  (file->d_name[len - 1] == 'm') &&
+          (file->d_name[len - 1] == 'm') &&
           (file->d_name[len - 2] == 't') &&
           (file->d_name[len - 3] == 't') &&
           (file->d_name[len - 4] == '.'));
 }
 
+#endif
+
 Uint8 conv_char2towercode(wchar_t ch) {
   if (ch)
     for (int x = 0; x < NUM_TBLOCKS; x++)
@@ -136,6 +148,7 @@ char conv_towercode2char(Uint8 code) {
   return towerblockdata[TB_EMPTY].ch;
 }
 
+
 static void add_mission(char *fname) {
 
   char mname[30];
@@ -212,6 +225,7 @@ static void add_mission(char *fname) {
   fclose(f);
 }
 
+#ifndef CREATOR
 
 void lev_findmissions() {
 
@@ -293,6 +307,8 @@ void lev_findmissions() {
 
 }
 
+#endif
+
 void lev_done() {
   if (mission) {
     delete [] mission;
@@ -444,7 +460,7 @@ void lev_selecttower(Uint8 number) {
         // get tower demo
         Uint16 *tmpbuf = NULL;
         Uint16 tmpbuf_len = mission[towerstart];
-        tmpbuf_len += long(mission[towerstart+1]) << 8;
+        tmpbuf_len += Uint16(mission[towerstart+1]) << 8;
         Uint16 ofs = 2;
 
         if (tmpbuf_len) {
@@ -643,7 +659,8 @@ bool lev_is_door_upperend(int row, int col) {
 /* returns true if the given position contains a door */
 bool lev_is_door(int row, int col) {
   return (tower[row][col] == TB_DOOR ||
-          tower[row][col] == TB_DOOR_TARGET);
+          tower[row][col] == TB_DOOR_TARGET ||
+          tower[row][col] == TB_STICK_DOOR);
 }
 
 /* returns true, if the given fiels contains a target door */
@@ -654,37 +671,39 @@ bool lev_is_targetdoor(int row, int col) {
 /**************** everything for elevators ******************/
 
 bool lev_is_station(int row, int col) {
-  return ((towerblockdata[tower[row][col]].tf & TBF_STATION));
+  return ((towerblockdata[tower[row][col]].tf & TBF_STATION) != 0);
 }
 bool lev_is_up_station(int row, int col) {
-   return ((tower[row][col] == TB_ELEV_BOTTOM) ||
-	   (tower[row][col] == TB_ELEV_MIDDLE));
+  return ((tower[row][col] == TB_ELEV_BOTTOM) ||
+          (tower[row][col] == TB_ELEV_MIDDLE));
 }
 bool lev_is_down_station(int row, int col) {
-   return ((tower[row][col] == TB_ELEV_TOP) ||
-	   (tower[row][col] == TB_ELEV_MIDDLE));
+  return ((tower[row][col] == TB_ELEV_TOP) ||
+          (tower[row][col] == TB_ELEV_MIDDLE));
 }
 bool lev_is_bottom_station(int row, int col) {
    return (tower[row][col] == TB_ELEV_BOTTOM);
 }
 
 bool lev_is_platform(int row, int col) {
-  return ((towerblockdata[tower[row][col]].tf & TBF_PLATFORM));
+  return ((towerblockdata[tower[row][col]].tf & TBF_PLATFORM) != 0);
 }
 bool lev_is_stick(int row, int col) {
   return ((tower[row][col] == TB_STICK) ||
-	  (tower[row][col] == TB_STICK_TOP) ||
-	  (tower[row][col] == TB_STICK_MIDDLE) ||
-	  (tower[row][col] == TB_STICK_BOTTOM));
+          (tower[row][col] == TB_STICK_TOP) ||
+          (tower[row][col] == TB_STICK_MIDDLE) ||
+          (tower[row][col] == TB_STICK_BOTTOM) ||
+          (tower[row][col] == TB_STICK_DOOR) ||
+          (tower[row][col] == TB_STICK_DOOR_TARGET));
 }
 
 bool lev_is_elevator(int row, int col) {
   return ((tower[row][col] == TB_STICK_BOTTOM) ||
-	  (tower[row][col] == TB_STICK_MIDDLE) ||
-	  (tower[row][col] == TB_STICK_TOP) ||
-	  (tower[row][col] == TB_ELEV_BOTTOM) ||
-	  (tower[row][col] == TB_ELEV_MIDDLE) ||
-	  (tower[row][col] == TB_ELEV_TOP));
+          (tower[row][col] == TB_STICK_MIDDLE) ||
+          (tower[row][col] == TB_STICK_TOP) ||
+          (tower[row][col] == TB_ELEV_BOTTOM) ||
+          (tower[row][col] == TB_ELEV_MIDDLE) ||
+          (tower[row][col] == TB_ELEV_TOP));
 }
 
 void lev_platform2stick(int row, int col) {
@@ -697,24 +716,32 @@ void lev_stick2platform(int row, int col) {
   if (tower[row][col] == TB_STICK_TOP) tower[row][col] = TB_ELEV_TOP;
   else if (tower[row][col] == TB_STICK_MIDDLE) tower[row][col] = TB_ELEV_MIDDLE;
   else if (tower[row][col] == TB_STICK_BOTTOM) tower[row][col] = TB_ELEV_BOTTOM;
+  else if (tower[row][col] == TB_STICK_DOOR) tower[row][col] = TB_ELEV_DOOR;
+  else if (tower[row][col] == TB_STICK_DOOR_TARGET) tower[row][col] = TB_ELEV_DOOR_TARGET;
   else if (tower[row][col] == TB_STICK) tower[row][col] = TB_STEP;
 }
 void lev_stick2empty(int row, int col) {
   if (tower[row][col] == TB_STICK_TOP) tower[row][col] = TB_STATION_TOP;
   else if (tower[row][col] == TB_STICK_MIDDLE) tower[row][col] = TB_STATION_MIDDLE;
   else if (tower[row][col] == TB_STICK_BOTTOM) tower[row][col] = TB_STATION_BOTTOM;
+  else if (tower[row][col] == TB_STICK_DOOR_TARGET) tower[row][col] = TB_DOOR_TARGET;
+  else if (tower[row][col] == TB_STICK_DOOR) tower[row][col] = TB_DOOR;
   else if (tower[row][col] == TB_STICK) tower[row][col] = TB_EMPTY;
 }
 void lev_empty2stick(int row, int col) {
   if (tower[row][col] == TB_STATION_TOP) tower[row][col] = TB_STICK_TOP;
   else if (tower[row][col] == TB_STATION_MIDDLE) tower[row][col] = TB_STICK_MIDDLE;
   else if (tower[row][col] == TB_STATION_BOTTOM) tower[row][col] = TB_STICK_BOTTOM;
+  else if (tower[row][col] == TB_DOOR) tower[row][col] = TB_STICK_DOOR;
+  else if (tower[row][col] == TB_DOOR_TARGET) tower[row][col] = TB_STICK_DOOR_TARGET;
   else if (tower[row][col] == TB_EMPTY) tower[row][col] = TB_STICK;
 }
 void lev_platform2empty(int row, int col) {
   if (tower[row][col] == TB_ELEV_TOP) tower[row][col] = TB_STATION_TOP;
   else if (tower[row][col] == TB_ELEV_MIDDLE) tower[row][col] = TB_STATION_MIDDLE;
   else if (tower[row][col] == TB_ELEV_BOTTOM) tower[row][col] = TB_STATION_BOTTOM;
+  else if (tower[row][col] == TB_ELEV_DOOR_TARGET) tower[row][col] = TB_DOOR_TARGET;
+  else if (tower[row][col] == TB_ELEV_DOOR) tower[row][col] = TB_DOOR;
   else if (tower[row][col] == TB_STEP) tower[row][col] = TB_EMPTY;
 }
 
@@ -729,14 +756,15 @@ bool lev_is_box(int row, int col) {
 
 int lev_is_sliding(int row, int col) {
     return ((tower[row][col] == TB_STEP_LSLIDER) ? 1 :
-	    (tower[row][col] == TB_STEP_RSLIDER) ? -1 : 
-	    0);
+            (tower[row][col] == TB_STEP_RSLIDER) ? -1 : 
+            0);
 }
 
 bool lev_is_robot(int row, int col) {
-  return ((towerblockdata[tower[row][col]].tf & TBF_ROBOT));
+  return ((towerblockdata[tower[row][col]].tf & TBF_ROBOT) != 0);
 }
 
+#ifndef CREATOR
 
 /* returns true, if the given figure can be at the given position
  without colliding with fixed objects of the tower */
@@ -793,6 +821,8 @@ bool lev_testfigure(long angle, long vert, long back,
   return true;
 }
 
+#endif
+
 unsigned char lev_putplatform(int row, int col) {
   unsigned char erg = tower[row][col];
 
@@ -890,6 +920,8 @@ bool lev_loadtower(const char *fname) {
   return true;
 }
 
+#ifndef CREATOR
+
 bool lev_savetower(const char *fname) {
   FILE *out = create_local_data_file(fname);
 
@@ -933,6 +965,8 @@ bool lev_savetower(const char *fname) {
   return true;
 }
 
+#endif
+
 /* rotate row clock and counter clockwise */
 void lev_rotaterow(int row, bool clockwise) {
   if (clockwise) {
@@ -1082,7 +1116,7 @@ lev_problem lev_is_consistent(int &row, int &col) {
   }
   for (y = 2; y < 5; y++)
     if ((towerblockdata[tower[y][0]].tf & TBF_DEADLY) ||
-	!(towerblockdata[tower[y][0]].tf & TBF_EMPTY)) {
+        !(towerblockdata[tower[y][0]].tf & TBF_EMPTY)) {
       row = y;
       col = 0;
       return TPROB_STARTBLOCKED;
@@ -1094,9 +1128,9 @@ lev_problem lev_is_consistent(int &row, int &col) {
     for (int c = 0; c < TOWERWID; c++) { 
       // check for undefined symbols
       if (tower[r][c] >= NUM_TBLOCKS) {
-	  row = r;
-	  col = c;
-	  return TPROB_UNDEFBLOCK;
+          row = r;
+          col = c;
+          return TPROB_UNDEFBLOCK;
       }
 
       // check if elevators always have an opposing end without unremovable
@@ -1114,7 +1148,9 @@ lev_problem lev_is_consistent(int &row, int &col) {
               (tower[d][c] != TB_ROBOT7) &&
               (tower[d][c] != TB_BOX) &&
               (tower[d][c] != TB_STATION_MIDDLE) &&
-              (tower[d][c] != TB_STEP_VANISHER)) {
+              (tower[d][c] != TB_STEP_VANISHER) &&
+              (tower[d][c] != TB_DOOR) &&
+              (tower[d][c] != TB_DOOR_TARGET)) {
             row = r;
             col = c;
             return TPROB_ELEVATORBLOCKED;
@@ -1141,6 +1177,8 @@ lev_problem lev_is_consistent(int &row, int &col) {
               (tower[d][c] != TB_ROBOT7) &&
               (tower[d][c] != TB_BOX) &&
               (tower[d][c] != TB_STATION_MIDDLE) &&
+              (tower[d][c] != TB_DOOR) &&
+              (tower[d][c] != TB_DOOR_TARGET) &&
               (tower[d][c] != TB_STEP_VANISHER)) {
             row = r;
             col = c;
@@ -1165,6 +1203,8 @@ lev_problem lev_is_consistent(int &row, int &col) {
               (tower[d][c] != TB_ROBOT7) &&
               (tower[d][c] != TB_BOX) &&
               (tower[d][c] != TB_STATION_MIDDLE) &&
+              (tower[d][c] != TB_DOOR) &&
+              (tower[d][c] != TB_DOOR_TARGET) &&
               (tower[d][c] != TB_STEP_VANISHER)) {
             row = r;
             col = c;
@@ -1192,6 +1232,8 @@ lev_problem lev_is_consistent(int &row, int &col) {
               (tower[d][c] != TB_ROBOT7) &&
               (tower[d][c] != TB_BOX) &&
               (tower[d][c] != TB_STATION_MIDDLE) &&
+              (tower[d][c] != TB_DOOR) &&
+              (tower[d][c] != TB_DOOR_TARGET) &&
               (tower[d][c] != TB_STEP_VANISHER)) {
             row = r;
             col = c;
@@ -1266,7 +1308,7 @@ static Uint8 nmission = 0;
 static Uint32 missionidx[256];
 
 bool lev_mission_new(char * name, Uint8 prio) {
-  assert(!fmission, _("called mission_finish twice"));
+  assert(!fmission, "called mission_finish twice");
 
   char fname[200];
   snprintf(fname, 200, "%s.ttm", name);
@@ -1307,7 +1349,7 @@ void write_fmission_section(Uint8 section, Uint32 section_len) {
 }
 
 void lev_mission_addtower(char * name) {
-  assert(fmission, _("called mission_addtower without mission_new"));
+  assert(fmission, "called mission_addtower without mission_new");
 
   Uint8 rows, col;
   Sint16 row;
@@ -1437,7 +1479,7 @@ void lev_mission_addtower(char * name) {
 }
 
 void lev_mission_finish() {
-  assert(fmission, _("called mission_finish without mission_new"));
+  assert(fmission, "called mission_finish without mission_new");
 
   Uint8 c;
 
