@@ -1,5 +1,5 @@
 /* Tower Toppler - Nebulus
- * Copyright (C) 2000-2003  Andreas Rver
+ * Copyright (C) 2000-2004  Andreas Rver
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -442,7 +442,7 @@ static void le_showkeyhelp(int row, int col) {
       if (tabbuf2[2] < '0') tabbuf2[2] = '0';
 
       snprintf(tmpb, 256, "~T%s%%s~T%s%%s", tabbuf2, tabbuf1);
-      snprintf(buf, 256, tmpb, knam, gettext(_ed_key_actions[_ed_keys[k].action]));
+      snprintf(buf, 256, tmpb, knam, _(_ed_key_actions[_ed_keys[k].action]));
 
       ts->addline(buf);
   }
@@ -749,9 +749,9 @@ void le_edit(void) {
 	    gam_newgame();
 	    rob_initialize();
 	    snb_init();
-	    snd_wateron();
+	    ttsounds::instance()->startsound(SND_WATER);
 	    gam_towergame(dummy1, dummy2, demolen, &demobuf);
-	    snd_wateroff();
+	    ttsounds::instance()->stopsound(SND_WATER);
 	    lev_restore(p);
 	    lev_set_towerdemo(demolen, demobuf);
 	    key_readkey();
@@ -773,9 +773,9 @@ void le_edit(void) {
 		gam_newgame();
 		rob_initialize();
 		snb_init();
-		snd_wateron();
+		ttsounds::instance()->startsound(SND_WATER);
 		gam_towergame(dummy1, dummy2, demolen, &demobuf);
-		snd_wateroff();
+		ttsounds::instance()->stopsound(SND_WATER);
 		lev_restore(p);
 		key_readkey();
 		set_men_bgproc(editor_background_proc);
@@ -798,9 +798,9 @@ void le_edit(void) {
           gam_newgame();
           rob_initialize();
           snb_init();
-          snd_wateron();
+          ttsounds::instance()->startsound(SND_WATER);
           gam_towergame(dummy1, dummy2, dummy3, &dummybuf);
-          snd_wateroff();
+          ttsounds::instance()->stopsound(SND_WATER);
           lev_restore(p);
           key_readkey();
           set_men_bgproc(editor_background_proc);
