@@ -1,5 +1,5 @@
 /* Tower Toppler - Nebulus
- * Copyright (C) 2000-2003  Andreas Rver
+ * Copyright (C) 2000-2004  Andreas Rver
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -58,14 +58,14 @@ static void men_reload_sprites(Uint8 what) {
   Uint8 pal[3*256];
 
   if (what & 1) {
-    file fi(&dataarchive, menudat);
+    file fi(dataarchive, menudat);
 
     scr_read_palette(&fi, pal);
     menupicture = scr_loadsprites(&restsprites, &fi, 1, 640, 480, false, pal, 0);
   }
 
   if (what & 2) {
-    file fi(&dataarchive, titledat);
+    file fi(dataarchive, titledat);
 
     scr_read_palette(&fi, pal);
     titledata = scr_loadsprites(&fontsprites, &fi, 1, SPR_TITLEWID, SPR_TITLEHEI, true, pal, config.use_alpha_font());
@@ -295,8 +295,6 @@ men_options_sounds(_menusystem *ms)
       config.nosound(false);
       snd_init();
     } else {
-      snd_stoptitle();
-      snd_stoptgame();
       snd_done();
       config.nosound(true);
     }
@@ -457,7 +455,7 @@ men_options_graphic(_menusystem *mainmenu) {
     ms = add_menu_option(ms, NULL, men_options_windowed);
     ms = add_menu_option(ms, NULL, men_alpha_options);
     ms = add_menu_option(ms, NULL, men_waves_menu, SDLK_UNKNOWN, MOF_PASSKEYS);
-    ms = add_menu_option(ms, NULL, men_full_scroller, SDLK_UNKNOWN, MOF_RIGHT);
+    ms = add_menu_option(ms, NULL, men_full_scroller, SDLK_UNKNOWN);
 
     ms = add_menu_option(ms, NULL, NULL);
     ms = add_menu_option(ms, _("Back"), NULL);
@@ -726,23 +724,21 @@ main_game_loop()
 
   gam_newgame();
   bns_restart();
-
+    
   do {
-    snd_wateron();
+    ttsounds::instance()->startsound(SND_WATER);
     do {
       gam_loadtower(tower);
       scr_settowercolor(lev_towercol_red(), lev_towercol_green(), lev_towercol_blue());
-      snd_watervolume(128);
-      snd_playtgame();
+      ttsounds::instance()->setsoundvol(SND_WATER, 128);
       gam_arrival();
       gameresult = gam_towergame(anglepos, resttime, demo, &tmpbuf);
-      snd_stoptgame();
     } while ((gameresult == GAME_DIED) && pts_lifesleft());
 
     if (gameresult == GAME_FINISHED) {
       gam_pick_up(anglepos, resttime);
 
-      snd_wateroff();
+      ttsounds::instance()->stopsound(SND_WATER);
       tower++;
 
       if (tower < lev_towercount()) {
@@ -755,7 +751,7 @@ main_game_loop()
             gameresult = GAME_ABORTED;
       }
     } else {
-      snd_wateroff();
+      ttsounds::instance()->stopsound(SND_WATER);
     }
   } while (pts_lifesleft() && (tower < lev_towercount()) && (gameresult != GAME_ABORTED));
 
@@ -768,12 +764,10 @@ static const char *
 men_main_bonusgame_proc(_menusystem *ms)
 {
   if (ms) {
-    snd_stoptitle();
     gam_newgame();
     scr_settowercolor(rand() % 256, rand() % 256, rand() % 256);
     lev_set_towercol(rand() % 256, rand() % 256, rand() % 256);
     bns_game();
-    snd_playtitle();
   }
   return _("Hunt the Fish");
 }
@@ -787,9 +781,7 @@ men_main_startgame_proc(_menusystem *ms)
     switch (key_sdlkey2conv(ms->key, false)) {
     case fire_key:
       dcl_update_speed(config.game_speed());
-      snd_stoptitle();
       main_game_loop();
-      snd_playtitle();
       dcl_update_speed(MENU_DCLSPEED);
       break;
     case right_key: currentmission = (currentmission + 1) % missioncount; break;
@@ -798,7 +790,7 @@ men_main_startgame_proc(_menusystem *ms)
     }
   }
   static char s[30];
-  snprintf(s, 30, _("%c Start: %s %c"), fontptrleft, gettext(lev_missionname(currentmission)), fontptrright);
+  snprintf(s, 30, _("%c Start: %s %c"), fontptrleft, _(lev_missionname(currentmission)), fontptrright);
   return s;
 }
 
@@ -815,10 +807,10 @@ static const char *
 men_main_leveleditor_proc(_menusystem *ms)
 {
   if (ms) {
-    snd_stoptitle();
+    //snd_stoptitle();
     le_edit();
     (void)key_sdlkey();
-    snd_playtitle();
+    //snd_playtitle();
   }
   return _("Level Editor");
 }
@@ -857,19 +849,14 @@ men_main_timer_proc(_menusystem *ms)
     lev_get_towerdemo(demolen, demobuf);
 
     dcl_update_speed(config.game_speed());
-    snd_stoptitle();
     gam_newgame();
-    snd_wateron();
+    ttsounds::instance()->startsound(SND_WATER);
     scr_settowercolor(lev_towercol_red(), lev_towercol_green(), lev_towercol_blue());
-    snd_watervolume(128);
-    snd_playtgame();
+    ttsounds::instance()->setsoundvol(SND_WATER, 128);
     rob_initialize();
     (void)gam_towergame(anglepos, resttime, demolen, &demobuf);
-    snd_stoptgame();
-    snd_wateroff();
+    ttsounds::instance()->stopsound(SND_WATER);
     dcl_update_speed(MENU_DCLSPEED);
-
-    snd_playtitle();
   }
   return NULL;
 }
@@ -922,8 +909,6 @@ void men_main() {
 
   if (!ms) return;
 
-  snd_playtitle();
-
   ms = set_menu_system_timeproc(ms, 200, men_main_timer_proc);
 
   ms = add_menu_option(ms, NULL, men_main_startgame_proc, SDLK_s, MOF_PASSKEYS);
@@ -942,8 +927,6 @@ void men_main() {
   ms = run_menu_system(ms, 0);
 
   free_menu_system(ms);
-
-  snd_stoptitle();
 }
 
 bool men_game() {
