@@ -1,5 +1,5 @@
 /* Tower Toppler - Nebulus
- * Copyright (C) 2000-2003  Andreas Rver
+ * Copyright (C) 2000-2004  Andreas Rver
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -91,8 +91,10 @@ static struct {
 
 /* bonus game scrolling layer */
 typedef struct  {
-  long width;    // width of the layer
-  int  num, den; // speed
+  long xpos, ypos;    // position of the layer
+  long xrepeat;       // how often the image repeats
+  long width, height; // size of the layer
+  int  num, den;      // speed
   Uint16 image;
 } _scroll_layer;
 
@@ -329,7 +331,7 @@ static void loadgraphics(Uint8 what) {
 
   if (what == 0xff) {
 
-    file fi(&dataarchive, grafdat);
+    file fi(dataarchive, grafdat);
   
     fi.read(towerpal, 2*256);
   
@@ -375,7 +377,7 @@ static void loadgraphics(Uint8 what) {
   }
 
   {
-    file fi(&dataarchive, topplerdat);
+    file fi(dataarchive, topplerdat);
     
     scr_read_palette(&fi, pal);
   
@@ -383,7 +385,7 @@ static void loadgraphics(Uint8 what) {
   }
 
   {
-    file fi(&dataarchive, spritedat);
+    file fi(dataarchive, spritedat);
 
     scr_read_palette(&fi, pal);
   
@@ -420,7 +422,7 @@ static void loadgraphics(Uint8 what) {
   }
 
   {
-    file fi(&dataarchive, crossdat);
+    file fi(dataarchive, crossdat);
 
     Uint8 numcol = fi.getbyte();
   
@@ -519,7 +521,7 @@ static void loadfont(void) {
   Uint16 c;
   int fontheight;
 
-  file fi(&dataarchive, fontdat);
+  file fi(dataarchive, fontdat);
 
   scr_read_palette(&fi, pal);
 
@@ -528,7 +530,7 @@ static void loadfont(void) {
   while (!fi.eof()) {
     c = fi.getword();
 
-    if (!c || (c >= MAXCHARNUM)) break;
+    if (!c) break;
 
     fontchars[c].width = fi.getbyte();
     fontchars[c].s = scr_loadsprites(&fontsprites, &fi, 1, fontchars[c].width, fontheight, true, pal, config.use_alpha_font());
@@ -537,7 +539,7 @@ static void loadfont(void) {
 
 static void loadscroller(void) {
 
-  file fi(&dataarchive, scrollerdat);
+  file fi(dataarchive, scrollerdat);
 
   Uint8 layers;
   Uint8 towerpos;
@@ -547,10 +549,10 @@ static void loadscroller(void) {
 
   num_scrolllayers = layers;
 
-  assert(num_scrolllayers > 1, _("Must have at least 2 scroll layers!"));
+  assert(num_scrolllayers > 1, "Must have at least 2 scroll layers!");
 
   scroll_layers = new _scroll_layer[layers];
-  assert(scroll_layers, _("Failed to alloc memory for bonus scroller!"));
+  assert(scroll_layers, "Failed to alloc memory for bonus scroller!");
     
   towerpos = fi.getbyte();
     
@@ -561,13 +563,19 @@ static void loadscroller(void) {
 
   for (int l = 0; l < layers; l++) {
 
+    scroll_layers[l].xpos = fi.getword();
+    scroll_layers[l].ypos = fi.getword();
     scroll_layers[l].width = fi.getword();
+    scroll_layers[l].height = fi.getword();
     scroll_layers[l].num = fi.getword();
     scroll_layers[l].den = fi.getword();
+    scroll_layers[l].xrepeat = fi.getword();
 
     scr_read_palette(&fi, pal);
 
-    scroll_layers[l].image = scr_loadsprites(&layersprites, &fi, 1, scroll_layers[l].width, 480, l != 0, pal, config.use_alpha_layers());
+    scroll_layers[l].image = scr_loadsprites(&layersprites, &fi, 1, 
+	scroll_layers[l].width, scroll_layers[l].height, 
+	l != 0, pal, config.use_alpha_layers());
   }
 }
 
@@ -632,7 +640,7 @@ void scr_init(void) {
 
 void scr_reinit() {
   display = SDL_SetVideoMode(SCREENWID, SCREENHEI, 16, (config.fullscreen()) ? (SDL_FULLSCREEN) : (0));
-  assert(display, _("could not open display"));
+  assert(display, "could not open display");
 }
 
 void scr_done(void) {
@@ -1033,6 +1041,8 @@ static void putcase(unsigned char w, long x, long h) {
   case TB_STICK:
   case TB_STICK_BOTTOM:
   case TB_STICK_MIDDLE:
+  case TB_STICK_DOOR:
+  case TB_STICK_DOOR_TARGET:
     scr_blit(restsprites.data(stick), x - (SPR_STICKWID / 2), h);
 
     break;
@@ -1313,7 +1323,7 @@ void scr_writeformattext(long x, long y, const char *s) {
         x += 32;
         break;
       default:
-        assert(0, _("Wrong command in formatted text."));
+        assert(0, "Wrong command in formatted text.");
       }
       break;
     default:
@@ -1399,7 +1409,7 @@ long scr_formattextlength(long x, long y, const char *s) {
         x += 32;
         break;
       default:
-        assert(0, _("Wrong command in formatted text."));
+        assert(0, "Wrong command in formatted text.");
       }
       break;
     default:
@@ -1692,11 +1702,12 @@ void scr_drawedit(long vpos, long apos, bool showtime) {
 }
 
 static void put_scrollerlayer(long horiz, int layer) {
-  horiz %= scroll_layers[layer].width;
-  scr_blit(layersprites.data(scroll_layers[layer].image), -horiz, 0);
-  if (horiz + SCREENWID > scroll_layers[layer].width)
+  horiz += scroll_layers[layer].xpos;
+  horiz %= scroll_layers[layer].xrepeat;
+  scr_blit(layersprites.data(scroll_layers[layer].image), -horiz, scroll_layers[layer].ypos);
+  if (horiz + SCREENWID > scroll_layers[layer].xrepeat)
     scr_blit(layersprites.data(scroll_layers[layer].image),
-             scroll_layers[layer].width - horiz, 0);
+             scroll_layers[layer].width - horiz, scroll_layers[layer].ypos);
 }
 
 void scr_draw_bonus1(long horiz, long towerpos) {
